Coverage for C:\src\imod-python\imod\flow\chd.py: 100%

1 from imod.flow.pkgbase import BoundaryCondition

2

3

4 class ConstantHead(BoundaryCondition):

5 """

6 The Constant Head package. The Time-Variant Specified-Head package is used

7 to simulate specified head boundaries that can change between

8 stress periods.

9

10 Parameters

11 ----------

12 head: xr.DataArray of floats

13 is the head at the boundary

14 """

15

16 _pkg_id = "chd"

17 _variable_order = ["head"]

18

19 def __init__(self, head):

20 super().__init__()

21 self.dataset["head"] = head